package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`*``!````W!0!`#0```!\D@````0`!30`(``)
M`"@`'``;``$``'#4@P``U(,!`-2#`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!`````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0#@@P``X(,```4`````$```
M`0```.B.``#HG@$`Z)X!`#P"``!H`@``!@`````0```"````"(\```B?`0`(
MGP$`^````/@````&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DZ(X`
M`.B>`0#HG@$`&`$``!@!```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`$3OZ9S5K1U5LK,;1HG_(G?0^1&4$
M````$`````$```!'3E4```````,````"`````````'8````%````$`````D`
M``"@"*0"@>4#D@@*RD`&40`Y@@`"1PHA`!&D0```!+K`D`*``@@0D$`D0B`"
M(8`0P"!```$TP&0`"!07!)P@L4:@``````4`````````!@`````````'````
M```````````(````"0````H````+````#0`````````````````````````.
M``````````\````0`````````````````````````!$````3`````````!0`
M````````%0`````````````````````````6````%P```!@`````````````
M````````````&0```!H``````````````!L`````````'````!X`````````
M`````!\````@`````````"$````B````(P```"0`````````)0```"8````G
M````*0```"H````K````````````````````+````"T``````````````"X`
M```O````,````#$````R````,P```#0``````````````#4````V````````
M````````````````````````````````````````````-P`````````Y````
M.P```#T````^````/P```$$```````````````````!"````````````````
M````0P```$0``````````````````````````````$4`````````1@```,DY
M0!\+BA!7][[\D>G[P\*'\)9\D76"#>PL]HMAF.\28]#Z@C]^EGP;G]:])76"
M#3Z>0D3)U;)QTU$$A.W>DQS/2J[_IYN3''V0$.FM<`ZO+TX]]BT.L7-9.T`?
M[#^0`BO0X2(]K3D-(6)D![N5DQSKA(H<PXZ'_U'N$>/-/PROGR+'J*-:[Y!V
M;^-P\]O3':,"]ADMW_Y(F2+4:$%-G7S;]P!>!Z2'_S&X@@V=NY,<I]VC:P$C
M^:2]T$M]41M]7V]Z:?IG62_E!#*EA8%T@@UZ\$IK?>T1#\2YG$#W(\X@[PM1
M^5^6DQQ"9DL0WX4@3_W2[P]7DEI2A_F<@1?J6O''#N`].?*+'```````````
M```````````0```````````````@````@@$`````````````%@````$`````
M`````````"`````L```````````````@````E0$`````````````$@```&X`
M```PH0$``0```!$`&`!6`@`````````````2````3@$`````````````$@``
M`!X!`````````````!(```"I`@`````````````2````;P$`````````````
M$@```,T!`````````````!(```#M```````````````2````I@$`````````
M````$@```.,!`````````````!(```"%`@`````````````2````8P$`````
M````````$@```/@```#D$0$``````!(```#B```````````````2````ZP$`
M````````````$@```/(!`````````````!(```"]`0`````````````2````
M>P``````````````$@```-0!`````````````!(```!>`@`````````````2
M````0`$`````````````$@```+(``````````````!(```!C````````````
M```2````LP$`````````````$@```'L!`````````````!(```#R`@``\)X!
M``0````1`!0`?@(`````````````$@```%<"`````````````!(````B`@``
M```````````2````2`(`````````````$@```,X"`````````````!(````Z
M`@`````````````2````JP$`````````````$@```),"`````````````!(`
M``#3````])X!`!,````1`!0`PP``````````````$@```)H`````````````
M`!(````9`0`````````````2````"`(`````````````$@```,0!````````
M`````!(```";`@`````````````2````C`(`````````````$@```/L!````
M`````````!(```#8`@``**$!``0````A`!@`MP(`````````````$@```*,`
M`````````````!(````R`0`````````````2````X`(`````````````$@``
M`!,"`````````````!(````+`0`````````````2````=P(`````````````
M$@```(H````T$`$``````!(```#(`@`````````````2````U@(``"BA`0`$
M````$0`8`-P!`````````````!(````I`@`````````````2````L`(`````
M````````$@````("`````````````!(````C`0`````````````2````#0(`
M````````````$@```%<``````````````!(```!&````4!(!```````2````
MH@(`````````````$@```#("`````````````!(```!P`@``.*$!``0````1
M`!@``%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?871F;W)K7VQO8VL`
M4&5R;%]M9U]S970`4&5R;%]N97=84P!03%]D;U]U;F1U;7``4&5R;%]S>7-?
M:6YI=#,`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<G5N`'!E<FQ?8V]N<W1R=6-T
M`%!E<FQ?;F5W6%-?9FQA9W,`4&5R;%]G=E]F971C:'!V`%!,7VUE;6]R>5]W
M<F%P`'!E<FQ?<&%R<V4`<&5R;%]A;&QO8P!097)L7V%T9F]R:U]U;FQO8VL`
M<&5R;%]D97-T<G5C=`!P97)L7V9R964`4&5R;%]S=E]S971P=FX`4&5R;%]S
M=E]S971P=@!097)L7W-Y<U]T97)M`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E
M<FQ?9V5T7W-V`%!E<FQ?<V%F97-Y<VUA;&QO8P!03%]C=7)R96YT7V-O;G1E
M>'0`7U]S=&%C:U]C:&M?9F%I;`!E>&ET`&QS965K-C0`<F5A9&1I<C8T`'-T
M<F1U<`!C;&]S961I<@!O<&5N-C0`<W1R<F-H<@!U;FQI;FL`;65M;6]V90!S
M=')T;VL`9V5T<'=U:60`<W1R;&5N`')M9&ER`')E860`;6MD:7(`7U]V9G!R
M:6YT9E]C:&L`9V5T<&ED`')E861L:6YK`')E86QL;V,`7U]S<')I;G1F7V-H
M:P!?7V9P<FEN=&9?8VAK`&QS=&%T-C0`7U]L:6)C7W-T87)T7VUA:6X`<W1D
M97)R`&UE;6-H<@!S=')C:'(`;65M8VUP`&UE;7-E=`!O<&5N9&ER`&=E='5I
M9`!A8V-E<W,`;65M8W!Y`'-T<F-M<`!?7V5R<FYO7VQO8V%T:6]N`&%B;W)T
M`'-T<FYC;7``7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?
M8VAK7V=U87)D`&QI8G!E<FPN<V\N-2XS.`!L:6)C+G-O+C8`;&0M;&EN=7@M
M87)M:&8N<V\N,P!'3$E"0U\R+C0`1TQ)0D-?,BXS,P!'3$E"0U\R+C,T````
M`0`!``$``0`#``$`!0`!``,``P`!``,``0`#``,``P`!``$``0`#``,``P`!
M``,``@`!``$``0`#``,`!``#``4``P`#``,``P`#``,``0`!``$``0`#``,`
M`P`#``,``P`#``$``0`#``,``0`#``$``P`#``,``P`#``,``0`#``$``0`#
M``,``P`!``$`'@,``!`````@````%&EI#0``!``R`P````````$``P`4`P``
M$`````````"SD98&```%`#P#```0````%&EI#0```P`R`P``$````+21E@8`
M``(`1P,`````````H0$`$P(```2A`0`5`P``\)X!`!0?``#TG@$`%"@``"BA
M`0`4.P``,*$!`!0&```XH0$`%$8```R@`0`6&0``$*`!`!8^```4H`$`%A4`
M`!B@`0`6+```'*`!`!8N```@H`$`%@\``"2@`0`6"0``**`!`!8*```LH`$`
M%CD``#"@`0`6!P``-*`!`!8_```XH`$`%C,``#R@`0`6$```0*`!`!8K``!$
MH`$`%A8``$B@`0`6!0``3*`!`!8U``!0H`$`%B$``%2@`0`6/```6*`!`!9%
M``!<H`$`%C<``&"@`0`6-```9*`!`!8]``!HH`$`%@T``&R@`0`6)@``<*`!
M`!8+``!TH`$`%B<``'B@`0`6#```?*`!`!8>``"`H`$`%C8``(2@`0`6*0``
MB*`!`!8#``",H`$`%B(``)"@`0`6#@``E*`!`!8P``"8H`$`%A<``)R@`0`6
M(```H*`!`!81``"DH`$`%C(``*B@`0`6)0``K*`!`!8(``"PH`$`%AP``+2@
M`0`600``N*`!`!8O``"\H`$`%A(``,"@`0`6&@``Q*`!`!9"``#(H`$`%A,`
M`,R@`0`6(P``T*`!`!8;``#4H`$`%C@``-B@`0`61```W*`!`!84``#@H`$`
M%D,``.2@`0`6&```Z*`!`!8=``#LH`$`%D```/"@`0`6*@``]*`!`!8D``#X
MH`$`%CH``/R@`0`6+0``"$`MZ5@!`.L(@+WH!.`MY03@G^4.X(_@"/"^Y3"0
M````QH_B"<J,XC#PO.4`QH_B"<J,XBCPO.4`QH_B"<J,XB#PO.4`QH_B"<J,
MXACPO.4`QH_B"<J,XA#PO.4`QH_B"<J,X@CPO.4`QH_B"<J,X@#PO.4`QH_B
M",J,XOC_O.4`QH_B",J,XO#_O.4`QH_B",J,XNC_O.4`QH_B",J,XN#_O.4`
MQH_B",J,XMC_O.4`QH_B",J,XM#_O.4`QH_B",J,XLC_O.4`QH_B",J,XL#_
MO.4`QH_B",J,XKC_O.4`QH_B",J,XK#_O.4`QH_B",J,XJC_O.4`QH_B",J,
MXJ#_O.4`QH_B",J,XIC_O.4`QH_B",J,XI#_O.4`QH_B",J,XHC_O.4`QH_B
M",J,XH#_O.4`QH_B",J,XGC_O.4`QH_B",J,XG#_O.4`QH_B",J,XFC_O.4`
MQH_B",J,XF#_O.4`QH_B",J,XEC_O.4`QH_B",J,XE#_O.4`QH_B",J,XDC_
MO.4`QH_B",J,XD#_O.4`QH_B",J,XCC_O.4`QH_B",J,XC#_O.4`QH_B",J,
MXBC_O.4`QH_B",J,XB#_O.4`QH_B",J,XAC_O.4`QH_B",J,XA#_O.4`QH_B
M",J,X@C_O.4`QH_B",J,X@#_O.4`QH_B",J,XOC^O.4`QH_B",J,XO#^O.4`
MQH_B",J,XNC^O.4`QH_B",J,XN#^O.4`QH_B",J,XMC^O.4`QH_B",J,XM#^
MO.4`QH_B",J,XLC^O.4`QH_B",J,XL#^O.4`QH_B",J,XKC^O.4`QH_B",J,
MXK#^O.4`QH_B",J,XJC^O.4`QH_B",J,XJ#^O.4`QH_B",J,XIC^O.4`QH_B
M",J,XI#^O.4`QH_B",J,XHC^O.4`QH_B",J,XH#^O.4`QH_B",J,XGC^O.4`
MQH_B",J,XG#^O.4`QH_B",J,XFC^O.4`QH_B",J,XF#^O.4`QH_B",J,XEC^
MO.4`QH_B",J,XE#^O.5P0"WI%#*?Y2#03>(4`(WE%`"-XA`0C>40$(WB#""-
MY0P@C>(`,)/E'#"-Y0`PH..D___KY"$!XP$@0.,"$*#A4`(!XP$`0..D"P#K
M,#$*XP$P0.,`0-/E``!4XT@```IP+QWNN#&?Y11@G>4$`(;B`V"&X@,PG^<'
M`7#C`R"2Y\XSTN4#,(/CSC/"Y5D``(H``:#A0%$*XP%00.-K___K$$"=Y0`P
MH.$$`(7E`""4Y0`@@.5@)03C`2!`XP0@@.44(0KC`2!`XPP@DN4(((#E9"4$
MXP$@0.,,((#E%`"=Y0$`4.-(``#:!!"$X@S`@^(`083@!."1Y`3@K.4!`%3A
M^___&@,`@.(`$*#C`!"-Y08@H.$`$8/G#`"5Y7P;`>,!$$#CB___ZP``4.,A
M```*#`"5Y3;__^L8$(WB`$"@X00#!.,!`$#C=0``ZP``4.,;```*#`"5Y1C_
M_^MW___KN#"?Y0`@D^4<,)WE`B`SX``PH.,H```:!`"@X2#0C>)P@+WH*___
MZT`A"N,!($#C``!0XPP`@N4=```*`?__ZX`PG^5P+QWN`S"?YP,PDN>N1L/E
MJO__Z@P`E>6#___KVO__Z@@`E>4``%#C`0``"@P'`.O>___J&!"-XJ`"!.,!
M`$#C3@``ZP``4.,(`(7EU___"O7__^KT'@GC`1!`XZ`$!.,!`$#C/?__ZP0`
MH..\___J`0"@XR3__^OM_O_K\)X!`-2-``"@C````+"@XP#@H.,$$)WD#2"@
MX00@+>4$`"WE'*"?Y1@PC^(#H(K@`#"@XP0P+>4,`)_E``":YZ_^_^M?___K
MZ(H```@!```4,)_E%""?Y0,PC^`"()/G``!2XQ[_+P$"___JT(H```0!```D
M`0KC`0!`XR0Q"N,!,$#C``!3X1[_+P$`,`#C`#!`XP``4^,>_R\!$_\OX20!
M"N,!`$#C)#$*XP$P0.,`,$/@HQ^@X4,1@>#!$+#A'O\O`0`P`.,`,$#C``!3
MXQ[_+P$3_R_A$$`MZ3Q!"N,!0$#C`##4Y0``4^,0@+T8W___ZP$PH.,`,,3E
M$("]Z.;__^KP1RWI`(!0XBL```HH,0KC`3!`XP"0D^4``%GC*```"@!0V.4!
M<*#A``!5XST`51,!4*`3`%"@`Q$``!H`0)GE``!4XPP```H)8*#A!`"@X04@
MH.$($*#A%O__ZP``4.,"```:!3#4YST`4^,+```*!$"VY0``5./S__\:!`"@
MX?"'O>@(4*#A`3#UY0``4^,]`%,3^___&@A01>#F___J"6!&X`%0A>(%0(3@
M1F&@X00`H.$`8(?E\(>]Z`A`H.'M___J"4"@X>O__^H00"WI`$"@X7`PG^5P
MT$WB#1"@X0`PD^5L,(WE`#"@XU[^_^L``%#C``"@$P0``!H0,)WE#SH#X@H*
M4^,!"5,3!P``"C0PG^4`()/E;#"=Y0(@,^``,*#C!P``&G#0C>(0@+WH`A"@
MXP0`H.')_O_K$`]OX:`"H.'Q___J6?[_Z_">`0#P0"WI`&!0XD`QG^5\T$WB
M`#"3Y70PC>4`,*#C`@``"@`PUN4``%/C!P``&APQG^4`()/E=#"=Y0(@,^``
M,*#C00``&GS0C>+P@+WH9?[_ZP!`4.+T__\*!`"@X;C^_^L``%#C*@``"A,P
MT.434(#B+@!3XP(``!H!,-7E``!3X_3__PH3,-#E+@!3XR4```H&`*#A:_[_
MZP!PH.$%`*#A:/[_ZP``A^`"`(#B4_[_ZP$0H.,`<*#A`"#@XP10C>5`,@3C
M`3!`XP!@C>5L_O_K"!"-X@<`H.$G_O_K`0!PXP<`H.$#```*&#"=Y0\Z`^(!
M"5/C$@``"B+^_^L'`*#A_/W_ZP0`H.&-_O_K``!0X]3__QH$`*#AF/[_ZP8`
MH.$`_O_KP/__Z@$PU>4N`%/CUO__&@(PU>4``%/CQ?__"M+__^JM___KZ___
MZ@3^_^OPG@$`<$`MZ0!@H.'D,)_E`=I-X@%0H.$(T$WB_R\`XP$*C>($$(WB
M!`"`X@`PD^4`,(#E`#"@XT@"!.,!`$#C"/[_ZP!`4.('``#:`2!$X@@PC>("
M,(/@!#!3Y0``4^,4```:``!2XQ$``!J(,)_E<`\=[@4@H.$&$*#A`S"?YP,`
MD.?T_?_K`1J-XF0PG^4$$('B`""3Y0`PD>4"(#/@`#"@XQ(``!H!VHWB"-"-
MXG"`O>@"0*#A!""@X2\0H.,$`(WB._[_ZP``4./F__\**`"?Y7#/'>X$,*#A
M!""-X@80H.$``)_G``"<YT/^_^OD___JQOW_Z_">`0`(B```H(<``/!'+>D!
M0*#A\#&?Y0C03>(`4*#A`#"3Y00PC>4`,*#C`##1Y3T`4^,!0($"!`"@X>_]
M_^L-$*#A`&"@X04`H.$%___K`)!0XCT```KH_?_K``!6X30``)H`@)WE*'$*
MXP%P0.,(@:#A`##5Y0``4^,]`%,3`3"@$P`PH`,%```*!3"@X0$@\^4``%+C
M/0!2$_O__QH%,$/@`@"&X@!@E^4#`(#@P/W_ZP``4.,(`(;G%0``"@`PE^4%
M`*#A"!"3YP$PT.0`,,'E``!3XST`4Q,&```*`2"!X@$PT.0"$*#A`3#"Y#T`
M4^,``%,3^?__&@$@H.$],*#C`##!Y0$PU.0!,.+E``!3X_O__QKL,)_E`""3
MY00PG>4"(#/@`#"@XS4``!H(T(WB\(>]Z`&02>(!,-3D`3#IY0``4^/[__\:
M\?__ZBAQ"N,!<$#C`("7Y0`PF.4``%/C)```"@@PH.$$(+/E"1"@X0&0B>(`
M`%+C^O__&@,0@>(!$:#A0#$*XP$P0.,`()/E``!2XP\``!H!`*#A`2"@XP`@
M@^6"_?_K`*!0XMC__PH($*#A"8&@X0@@H.$W_?_K`*"'Y0"0C>4!D(GB`#"@
MXPDQBN>E___J"`"@X5G]_^L`H*#A``!0XP``A^7(__\*"8&@X?+__^H#D*#A
M"!"@X]___^I#_?_K\)X!`&@`G^4`,PCC`3!`XQ!`+>EP3QWN"-!-XC0@`>,!
M($#C``"?YU@2!.,!$$#C``"4YX/]_^LX$)_E`,"@XUPU!.,!,$#C4"X"XP$@
M0.,!$)_G`0"4YW02!.,!$$#C!,"-Y0`PC>6._?_K"-"-XA"`O>A<A0``,(4`
M`"0`G^5PSQWN`#,(XP$P0.,T(`'C`2!`XU@2!.,!$$#C``"?YP``G.=G_?_J
MY(0``#!`+>G(,)_E`MI-XAS03>("&HWB%!"!X@`PD^4`,('E`#"@XT']_^L!
M$*#C`,"@X0$@`>,`P(WE#`"-XI@R!.,!,$#C!#"-Y8PR!.,!,$#C2_W_ZP$:
MC>(!*J#C$!"!X@P`C>(3_?_K`$!0XA8``+H!`(3B(?W_ZP!04.(2```*`1J-
MX@0@H.$0$('BW/S_ZP`PH.,$,,7G`AJ-XC`PG^44$('B`""3Y0`PD>4"(#/@
M`#"@XP,``!H%`*#A`MJ-XAS0C>(P@+WHY?S_ZP!0H./P___J\)X!`,C__^KP
M0RWI`&"@X1`RG^5"W4WB`4"@X0303>*@`@3C`0!`XT'-C>(0$(WB/,",X@`P
MD^4`,(SE`#"@XR7^_^LO$*#C`%"@X08`H.$-_?_K``!0XP\```H&$*#AK`($
MXP$`0.,$___K!@"@X4$=C>*L,9_E/!"!X@`@D^4`,)'E`B`SX``PH.-D```:
M0MV-X@30C>+P@[WH!`"@X;?\_^N\$@3C`1!`XR;]_^L`0%#BZ/__"@`PU.7(
M@@3C`8!`XWQPC>(``%/C.P``"@``5>,$```*!!"@X04`H.&`_/_K``!0XRL`
M``H$`*#AW_S_ZP$@0.("((3@`#"@X0(`5.$`D*#A`#"$,``0H#,!`(0R`P``
M.@@``.H#`%#A`!##Y0(```H!('/E+P!2X_G__PH$`*#AS?S_ZP"0H.$&`*#A
MROS_ZPD`@.`!`(#B`0I0X\#__RH!*J#C`1"@XP<`H.$(8(WE$`&-Z,`R!.,!
M,$#CS?S_ZQ`0C>('`*#AB/S_ZP``4.,#```:(#"=Y0\Z`^(""5/C%0``"@``
MH..\$@3C`1!`X^?\_^L`0%#BJ?__"@`PU.4``%/CP___&@``5>,"```*`##5
MY2X`4^,#```*G$($XP%`0.,!D*#CUO__Z@$PU>4``%/CZO__"O?__^H!$*#C
M!P"@X<_\_^L``%#CY/__&@<0H.&L`@3C`0!`XYG^_^L'`*#A6/S_ZY+__^I9
M_/_K\)X!`!!`+>DO$*#C`$"@X<G\_^L``%#C`4"`$@0`H.$00+WH3/S_ZG!`
M+>D`8%#B%#&?Y0':3>((T$WB`1J-X@00@>(`,)/E`#"!Y0`PH.,L```*`##6
MY0``4^,I```*>?S_ZP$@@.(`0*#A`0I2XS(``(H$4(WB!A"@X04`H.$@_/_K
M`3!$X@,PA>`%`%/A!P``F@`0H.,"``#J!0!3X0$0P^4"```*`2!3Y"\`4N/Y
M__\*+Q"@XP4`H.&>_/_K``!0XP\```H%`%#A`#"@@P`PP(4%`*#A'_S_ZP$:
MC>)D,)_E!!"!X@`@D^4`,)'E`B`SX``PH.,2```:`=J-X@C0C>)P@+WH`1J-
MXC@PG^4$$('B`""3Y0`PD>4"(#/@`#"@XP<``!J<`@3C`0!`XP':C>((T(WB
M<$"]Z`;\_^H``*#CY/__Z@;\_^OPG@$`,$`MZ<Q"!.,!0$#CF#2?Y0S03>(H
M40KC`5!`XP`PD^4$,(WE`#"@XPT0H.$$`*#A2_W_ZP``4.,,```*``"=Y0`0
ME>4`,8'@!""3Y0`A@><``%+C\___"@0P@^($()/E!""#Y```4N/[__\:[?__
MZMA"!.,!0$#C*%$*XP%00.,-$*#A!`"@X37]_^L``%#C#```"@``G>4`$)7E
M`#&!X`0@D^4`(8'G``!2X_/__PH$,(/B!""3Y00@@^0``%+C^___&NW__^K@
M0@3C`4!`XRA1"N,!4$#C#1"@X00`H.$?_?_K``!0XPP```H``)WE`!"5Y0`Q
M@>`$()/E`"&!YP``4N/S__\*!#"#X@0@D^4$((/D``!2X_O__QKM___J[$($
MXP%`0.,H40KC`5!`XPT0H.$$`*#A"?W_ZP``4.,,```*``"=Y0`0E>4`,8'@
M!""3Y0`A@><``%+C\___"@0P@^($()/E!""#Y```4N/[__\:[?__ZO1"!.,!
M0$#C*%$*XP%00.,-$*#A!`"@X?/\_^L``%#C#```"@``G>4`$)7E`#&!X`0@
MD^4`(8'G``!2X_/__PH$,(/B!""3Y00@@^0``%+C^___&NW__^H$0P3C`4!`
MXRA1"N,!4$#C#1"@X00`H.'=_/_K``!0XPP```H``)WE`!"5Y0`Q@>`$()/E
M`"&!YP``4N/S__\*!#"#X@0@D^4$((/D``!2X_O__QKM___JH$($XP%`0.,H
M40KC`5!`XPT0H.$$`*#AQ_S_ZP``4.,,```*``"=Y0`0E>4`,8'@!""3Y0`A
M@><``%+C\___"@0P@^($()/E!""#Y```4N/[__\:[?__ZA!#!.,!0$#C*%$*
MXP%00.,-$*#A!`"@X;'\_^L``%#C#```"@``G>4`$)7E`#&!X`0@D^4`(8'G
M``!2X_/__PH$,(/B!""3Y00@@^0``%+C^___&NW__^H<0P3C`4!`XRA1"N,!
M4$#C#1"@X00`H.&;_/_K``!0XPP```H``)WE`!"5Y0`Q@>`$()/E`"&!YP``
M4N/S__\*!#"#X@0@D^4$((/D``!2X_O__QKM___J*$,$XP%`0.,H40KC`5!`
MXPT0H.$$`*#AA?S_ZP``4.,,```*``"=Y0`0E>4`,8'@!""3Y0`A@><``%+C
M\___"@0P@^($()/E!""#Y```4N/[__\:[?__ZJQ"!.,!0$#C*%$*XP%00.,-
M$*#A!`"@X6_\_^L``%#C#```"@``G>4`$)7E`#&!X`0@D^4`(8'G``!2X_/_
M_PH$,(/B!""3Y00@@^0``%+C^___&NW__^H-$*#A-`,$XP$`0.-<_/_K`!!0
MX@(```H<`P3C`0!`XT#]_^L-$*#A2`,$XP$`0.-3_/_K`!!0X@(```I<`P3C
M`0!`XS?]_^L-$*#A:`,$XP$`0.-*_/_K`!!0X@\```J@`@3C`0!`XR[]_^M8
M,)_E`""3Y00PG>4"(#/@`#"@XQ```!J,$P3C`1!`X_0"!.,!`$#C#-"-XC!`
MO>@A_?_J#1"@X7@#!.,!`$#C-/S_ZP`04.+L__\*$`,$XP$`0.,8_?_KZ/__
MZMKZ_^OPG@$`!.`MY1`#!.,!`$#C#-!-XE0PG^4-$*#A`#"3Y00PC>4`,*#C
M(OS_ZP``4.,%```*``#0Y0``4.,P`%`3`0"@`P``H!,!`"#B'#"?Y0`@D^4$
M,)WE`B`SX``PH.,!```:#-"-X@3PG>2^^O_K\)X!``\`+>DX`0KC`0!`XP3@
M+>4!$*#C*,"?Y0S03>(``)#E%#"-X@`PC>40()WE`,"<Y03`C>4`P*#CV/K_
MZ_\`H./B^O_K\)X!`/!'+>D"$*#C`""@XP'83>(`,*#C&-!-X@"`H.$!Z(WB
M%.".X@`0C>5`$9_E`!"1Y0`0CN4`$*#CM_K_ZP$`4.(`<,'BQR^@X0(P(.`"
M,%/@<S#_Y@(P(^`",%/@`B#"X`-@4.`"<,?@``!7XS4``+H(D*#C`9!`XPQ0
MC>(`$*#C!B"@X0<PH.$(`*#A`!"-Y:'Z_^L!`''C`0!P`R\```H)(*#A!1"@
MX0@`H.%;^O_K`0!PXR8```H'`%#C'```F@@`0.(`0)7@&0``*A2A"N,!H$#C
M`@``Z@%`1.(%`%3A$P``.@@@H.,*$*#A!`"@X67Z_^L``%#C]O__&@5`1.`&
M`)3@Q!^GX`'(C>)<,)_E%,",X@`@D^4`,)SE`B`SX``PH.,0```:`=B-XAC0
MC>+PA[WH`6A6X@!PQ^(!`'?C`0AV`\S__QH``.#C`!"@X>S__^J@`P3C`0!`
MXY7__^N0`P3C`0!`XY+__^M/^O_K\)X!`!!`+>DK^O_K)/K_ZP``4.,``)`5
M$("]Z'!`+>D`4*#AT#"?Y1C03>*L`P3C`0!`XQ`0C>(`,)/E%#"-Y0`PH..0
M^__K`$!0X@(```H`,-3E``!3XPL``!J8,)_E`""3Y10PG>4"(#/@`#"@XP40
MH`&L`P0#`0!``QT``!H8T(WB<$"]Z&C\_^H%`*#A8_K_ZP!@H.$$`*#A8/K_
MZP``AN`"`(#B2_K_ZP$0H.,`(.#CO#($XP$P0.,`4(WE&`"-Z<`R!.,!,$#C
M`$"@X6+Z_^L@,)_E`""3Y10PG>4"(#/@`#"@XP00H`&L`P0#`0!``^'__PH0
M^O_K\)X!`/!/+>D`8*#A\#6?Y>S03>+L)9_E@%"-X@S@@^(`()+EY""-Y0`@
MH.,D0(/B!P"3Z`<`A>B8P(WB#P"^Z(QPC>(/`*SH`P">Z`,`C.@'`)3H!P"'
MZ!@0C>*@`@3C`0!`XTG[_^L`0%#B`@``"@`PU.4``%/C#@$`&L_Y_^O(^?_K
M``!0XW8```H`@)#E``!8XW,```H(`*#A(?K_ZX``H.$!`(#B#/K_ZP`PV.4`
M0*#A`'"@X0``4^,+```*Q),$XP&00.,$`*#A`#"-Y0$0H.,),*#A`"#@XP)`
MA.(?^O_K`3#XY0``4^/U__\:7`,$XP$`0..8@(WB`@``Z@0`N.4``%#C#0``
M"A@0C>(>^__K`$!0XOC__PH`,-3E``!3X_7__PI+^__K``!0X_+__PH$`*#A
MOOG_ZP!`4.(,```:!$"5Y```5.,)```*`##4Y0``4^/%```*!`"@X3W[_^L`
M`%#C\?__&@1`E>0``%3C]?__&@0`H.'(@@3C`8!`X^?Y_^L`H*#A!P"@X>3Y
M_^L`H(K@`:N*X@2@BN(*`*#AS?G_ZP$0H.,`D*#A`"#@XPQPC>78,P3C`3!`
MXP!`C>4(,(WES#,$XP$P0.,$@(WEXOG_ZP<=H.,)`*#AZ/G_ZP$`<.,#```:
MV?G_ZP`@D.41`%+CHP``&A@0C>()`*#A?/G_ZP!04.(J```*.`$*XP$`0.,`
M,);E'"0$XP$@0.,!$*#C``"0Y0"0C>7F^?_K`'"@X\@SG^4`()/EY#"=Y0(@
M,^``,*#CZ```&@<`H.'LT(WB\(^]Z'7Y_^L`@%#BA```&@0`E^0``%#C"0``
M"A@0C>+$^O_K`#!0XOC__PH`,-/E``!3X_+__QH$`)?D``!0X_7__QH-`*#C
MO(,$XP&`0..,^?_K4S"@XP!`H.$`<*#A@/__ZB@PG>4/.@/B`0E3X]#__QHP
M0)WE.OG_ZP``5.',__\:*#"=Y5,PZ.<'#5/CR/__&@H`H.%Z^?_K&!"-X@!P
MH.%P!`3C`0!`XZ'Z_^L`$%#B=```"@``EN5H_/_K`*!0XG````H*`*#A?_G_
MZP!`H.$#`%#C#```F@0`0.)X%`3C`1!`XP``BN`4^?_K``!0XP4``!H$`%3C
MEP``"@1`BN`%,%3E+P!3XY,```H8$(WB$`,$XP$`0..%^O_K``!0XP,```H`
M,-#E,`!3XP``4Q,$```:"@"@X0`0H.--^?_K`$!0XE$``!J,$P3C`1!`XQ`#
M!.,!`$#C7OO_ZUQE!.,!8$#C4OG_ZP$0H.,(`(WE!("-Y0<`H.$`D(WEI#0$
MXP$P0.,,8(WE`"#@X[2D!.,!H$#C6_G_ZP\``.I6^?_K`#"0Y1$`4^,1```:
M0/G_ZP%0A>(`P*#A"C"@X00@H.$!$*#C!P"@X1!@C>4,4(WE`!&-Z0"0C>5*
M^?_K!QV@XP<`H.%0^?_K`$"@X0$`<./I__\*"0"@X=_X_^L'$*#AH`($XP$`
M0.,R^__K!P"@X:O^_^MP___J`T"@X3[__^HI^?_K@`"@X0$`@.(&___J.`$*
MXP$`0.,`,);E`1"@XP0@C>7@(P3C`2!`XP"0C>4``)#E1OG_ZU[__^J8_O_K
M1#&?Y0`@D^7D,)WE`B`SX``PH.-'```:!`"@X>S0C>+P3[WHU/C_Z@"@EN6,
M___J*/[_ZP!@H.$`H%'BJ?__N@H@4.(`L*#C`##*X@0`H.$`L(WEYOC_ZP8@
MH..P$(WB!`"@X:/X_^L&`%#C,@``&K`@G>5#/*#C03-$XP,`4N&8__\:M"O=
MX4@U!.,#`%+AE/__&C(@5N($`*#A`##*X@"PC>72^/_K!`"@X;A`C>(H(*#C
M!!"@X8[X_^LH`%#C'0``&@<`H.$(0(WE!("-Y90T!.,!,$#C`)"-Y0`@X.-<
M%03C`1!`XPP0C>4!$*#CX+#-Y>OX_^NE___J!$"6Y0``5.-H__\*!`"@X=;X
M_^L#`%#C9/__F@0`0.*`%`3C`1!`XP``A.!L^/_K``!0XP2@H`%<___JDOC_
MZX@$!.,!`$#CT?W_ZPR#`0#PG@$`<$`MZ7!/'>XT(I_E"-!-XC`RG^4`()+E
M!""-Y0`@H.,-$*#A]`($XP$`0.,#,)_G`U"4YV@PU>5I,,7ET/G_ZP``4.,"
M```*`##0Y3$`4^-C```*<?S_Z^PQG^4#,)_G`U"4YP4`H.$#,*#C`2"@X\@4
M!.,!$$#CF_C_ZP!04.(,```*Q#&?Y1`@E>4#,)_G`!"2Y<PD!.,!($#C`P"4
MYW;X_^L0,)7E`!"3Y0@PD>4!!1/C5@``&I01G^4#,*#C`2"@XP$0G^<!`)3G
MU!0$XP$00..$^/_K`&!0X@L```H-$*#AK`($XP$`0..D^?_K`"!0XCX```I8
M,9_E$!"6Y0,PG^<`$)'E`P"4YUOX_^M`40KC`5!`XSPQG^4!(*#CV!0$XP$0
M0.,#,)_G`V"4YP8`H.&!^/_K\"0$XP$@0.,`$*#A!@"@X4SX_^L,,9_E`""@
MXPT0H.&@`@3C`0!`XP,PG^<#,)3G:2##Y83Y_^L`0*#A``!0XP@`A>4/```*
M!QV@XP0`H.%[^/_K`2"`X@`PH.$1`%#C`0!2$R(``(J<,)_E`""3Y00PG>4"
M(#/@`#"@XQL``!H(T(WB<("]Z`0`E>4+_O_K`$"@X0``4.,(`(7EZ?__&O@$
M!.,!`$#C7_C_ZP$PT.4``%/CG/__"I?__^I`40KC`5!`XQ`@EN4$,)7E``"2
MY0`0D^4%^O_KP/__ZD@PG^4#,)_G`P"4YV'X_^NC___J`OC_ZP00E>4<!03C
M`0!`XP0@H.$`$)'E1_C_Z_">`0!\<@``3'(``!QR``#D<0``J'$``(!Q``!(
M<0``D'```#!`+>D`0*#AY#"?Y0S03>(0`P3C`0!`XPT0H.$`,)/E!#"-Y0`P
MH.,[^?_K`#!0X@H```H`,-/E,`!3XP``4Q,!,*`#`#"@$P$P(^(``%3C`#"@
M`P$P`Q(``%/C!P``&HPPG^4`()/E!#"=Y0(@,^``,*#C'0``&@S0C>(P@+WH
M`##4Y0``4^/T__\*!`"@X7[[_^LO$*#C`%"@X4#X_^L``%#C`5"`$@4`H.'$
M]__K!""@X]@3!.,!$$#C1/C_ZP``4./E__\:)#"?Y0`@D^4$,)WE`B`SX``P
MH.,#```:!`"@X0S0C>(P0+WH7OG_ZK;W_^OPG@$`\$\MZ0`0H.',/)_EI]]-
MXD``@.(0((WB@&"!X@`PD^64,HWE`#"@XP!0H.,0$!#I!%""Y0Q0@N40((+B
M-$^_YA!``N4L-*#A#.2@X?\\`^((`(#B+#R#X?_H#N(,/(/A!@!0X0XP@^$(
M,`+E[O__&H8_C>((,(WEB#"=Y1@`C>(<H)WE#!"-Y0,0H.%X@)WE?""=Y1BP
MG>6`<)WEA&"=Y8S`G>404)WE%$"=Y02@C>4!``#J";"@X00PC>4!,*#A/."0
MY3@0D.4`H*#C")"PY72@@.4)$"'@"!`AX`>`H.$#<*#A!#"0Y040(>`+4*#A
M`^`NX`+@+N`&(*#A!.`NX`Q@H.&ASZ#A`1"1X([`C.$$0)WE#!"!X0C`G>5P
M$(#E``!<X0K`H.'A__\:#!"=Y1`@G>6X8)WE`!21Z`B0D>4,,)'E(`"1Y:I-
MH.$I4:#A$("1Y0-?A>&9.0?C@CI%XQBPD>6,0H3A`R"2X``@DN"*0H3A`D"4
MX`L@*.`)(`+@"5^%X0L@(N`%`"C@`D"4X!@@G>4*``#@`R"2X`@`(.`+()+@
M`."2X"H!H.$,#X#A(""=Y0H/@.'D[8[@`,`EX`,@DN`$P`S@"""2X`7`+.!D
M0:#A#,"2X"@@G>7NS8S@`R"2X`4@DN`$4"#@#E`%X&[AH.$`4"7@!5"2X#`@
MG>7L787@`R"2X``@DN`.`"3@#```X&S!H.$$`"#@``"2X#@@G>7E#8#@`R"2
MX`0@DN`,0"[@!4`$X&51H.$.0"3@!$"2X$`@G>7@383@`R"2X`X@DN`%X"S@
M`.`.X&`!H.$,X"[@#N"2X$@@G>7D[8[@`R"2X`P@DN``P"7@!,`,X&1!H.$%
MP"S@#,"2X%`@G>7NS8S@`R"2X`4@DN`$4"#@#E`%X&[AH.$`4"7@!5"2X%@@
MG>7L787@`R"2X``@DN`.`"3@#```X&S!H.$$`"#@``"2X&`@G>7E#8#@`R"2
MX`0@DN`,0"[@!4`$X&51H.$.0"3@!$"2X&@@G>7@383@`R"2X`X@DN`%X"S@
M`.`.X&`!H.$,X"[@#N"2X'`@G>7D[8[@`R"2X`P@DN``P"7@!,`,X&1!H.$%
MP"S@#,"2X'@@G>7NS8S@`R"2X`4@DN`$4"#@#E`%X&[AH.$`4"7@!5"2X(`@
MG>7L787@`R"2X``@DN`.`"3@#```X&S!H.$$`"#@`""2X(@`G>7E+8+@`P"0
MX`0`D.`,0"[@!4`$X&51H.$.0"3@!$"0X)``G>7B383@`P"0X`X`D.`%X"S@
M`N`.X&(AH.$,X"[@#N"0X)@`G>7D[8[@`P"0X`P`D.`"P"7@!,`,X&1!H.$%
MP"S@#,"0X*``G>7NS8S@`P"0X`4`D.`$4"+@#E`%X&[AH.$"4"7@!0"0X*A0
MG>7L#8#@`S"5X+!0G>4",)/@#B`DX`P@`N!LP:#A!"`BX`(PD^#@+8/@H3L.
MX]D^1N,#4)7@!%"5X`Q`+N``0"3@8`&@X01`E>`#4);@#E"5X,!@G>4`X"S@
MXDV$X`+@+N!B(:#A#N"5X`-0EN`,4)7@R&"=Y0+`(.#D[8[@!,`LX&1!H.$,
MP)7@`U"6X`!0E>#08)WE!``BX.[-C.`.`"#@;N&@X0``E>`#4);@`E"5X-A@
MG>4.("3@[`V`X`P@(N!LP:#A`B"5X`-0EN`$4)7@X&"=Y0Q`+N#@+8+@`$`D
MX&`!H.$$0)7@`V"6X`[@EN``4"S@Z&"=Y>)-A.`"4"7@8B&@X050GN#P<)WE
M`V"6X`+@(.`,P);@!.`NX&1AH.'D787@#N"<X`-PE^```)?@!L`BX/APG>5E
M0:#A!<`LX.7MCN`,P)#@`%&=Y0-PE^`$`";@#@`@X`(@E^#NS8S@`""2X&[A
MH.$#4)7@!G"5X`X`).`(89WE#``@X.PM@N```)?@;,&@X0-@EN`$8);@$%&=
MY0Q`+N#B#8#@`D`DX&(AH.$$0);@`U"5X!AAG>4.4)7@`N`LX.!-A.``X"[@
M8`&@X0[@E>`#4);@#%"5X"!AG>4`P"+@Y.V.X`3`+.!D0:#A#,"5X`-0EN`"
M4)7@*&&=Y00@(.#NS8S@#B`BX&[AH.$"()7@`V"6X```EN`.4"3@,&&=Y0Q0
M)>#L+8+@!5"0X&S!H.$#`);@!`"0X#AAG>4,0"[@XEV%X`)`).!B(:#A!$"0
MX`,`EN!`<9WE#@"0X`+@+.#E383@!>`NX`Y@D.!EX:#A`P"7X.1MAN`,`)#@
M#L`BX`3`+.!0<9WE#`"0X&3!H.%(09WEY@V`X&91H.$#,)3@!4",X0(PD^`,
M("[@!B`BX`!`!.`",)/@X"V#X-P\"^,;/TCC8`&@X0-@E^!8<9WE#N"6X`5@
M#.`&0(3A`&`%X`1`GN``X(7A`W"7X`+@#N`,P)?@!N".X0S@GN!@P9WEXDV$
MX&(AH.$#P)S@`F``X`7`G.`"4(#A:'&=Y010!>#D[8[@!E"%X61!H.$,P)7@
M!&""X0-0E^#NS8S@<'&=Y0!0E>`.8`;@;@&@X03@`N`.8(;A!6"6X`/@E^``
M4(3A`N">X`Q0!>#L+8;@`&`$X&S!H.$&4(7A@'&=Y0Y0E>!XX9WE#&``X.)=
MA>`#X)[@!.">X`Q`@.$"0`3@8B&@X09`A.$"8`S@#D"4X`/@E^``X)[@Y0V$
MX`)`C.&(<9WE!4`$X&51H.$&0(3A!6`"X`Y`E.`%X(+A`W"7X`#@#N`,P)?@
M!N".X0S@GN"0P9WEX$V$X&`!H.$#P)S@`&`%X`(@G.``P(7AF'&=Y03`#.`&
MP(SAY.V.X`+`G.!D0:#A`R"7X`1@`.`%()+@!%"`X:!QG>4.4`7@[LV,X`90
MA>%NX:#A`E"5X`,@E^`.8`3@`""2X.P-A>`.4(3AL'&=Y0Q0!>!LP:#A!E"%
MX0Q@#N`"()7@J%&=Y>`M@N`#4)7@!$"5X`Q0CN$`4`7@8`&@X090A>$`8`S@
M!$"5X`!0C.$#<)?@`E`%X.)-A.`&4(7A8B&@X0[@E^"X<9WE#N"5X`)0@.$"
M8`#@`W"7X`10!>`&4(7A#,"7X`S`E>#`49WEY.V.X&1!H.$#4)7@!&`"X```
ME>`$4(+A#E`%X.[-C.`&4(7A;N&@X<AQG>4``)7@#E"$X0Y@!.`#<)?@#%`%
MX.P-@.`"()?@!E"%X=!QG>5LP:#A`E"5X.`MA>`,4([A#&`.X`-PE^``4`7@
M!$"7X`90A>%@`:#A!%"5X`!@H./B387@V%&=Y>!QG>4#4)7@!&"!Y0[@E>``
M4(SA`E`%X`Q@@>448('E8B&@X1Q@@>4`8`S@!E"%X0)@`.`.X)7@`U"7X`Q0
ME>`"P(#AZ'&=Y03`#.#D[8[@!L",X61!H.$%P)S@`W"7X`0P@N$$4`+@#C`#
MX.[-C.```)?@!3"#X?!AG>4`,)/@;N&@X>P-@^#6,0SC8CI,XP-0EN#X89WE
M`E"5X`X@).`,("+@;,&@X0(@E>`#4);@!%"5X`!BG>4,0"[@X"V"X`!`).!@
M`:#A!$"5X`-0EN`.4)7@"&*=Y0#@+.#B383@`N`NX&(AH.$.X)7@`U"6X`Q0
ME>`08IWE`L`@X.3MCN`$P"S@9$&@X0S`E>`#4);@`%"5X!ABG>4$`"+@[LV,
MX`X`(.!NX:#A``"5X`-0EN`"4)7@(&*=Y0X@).#L#8#@#"`BX&S!H.$"()7@
M`U"6X`10E>`H8IWE#$`NX.`M@N``0"3@8`&@X01`E>`#4);@#E"5X#!BG>4`
MX"S@XDV$X`+@+N!B(:#A#N"5X`-0EN`,4)7@.&*=Y0+`(.#D[8[@!,`LX&1!
MH.$,P)7@`U"6X`!0E>!`8IWE!``BX.[-C.`.`"#@;N&@X0``E>`#4);@`E"5
MX$ABG>4.("3@[`V`X`P@(N!LP:#A`B"5X`-0EN`$4)7@4&*=Y0Q`+N#@+8+@
M`$`DX&`!H.$$0)7@`U"6X`Y0E>!88IWE`.`LX.)-A.`"X"[@8B&@X0[@E>`#
M4);@#%"5X&!BG>4"P"#@Y.V.X`3`+.!D0:#A#,"5X`-0EN``4)7@:&*=Y00`
M(N#NS8S@#@`@X&[AH.$``)7@`U"6X`)0E>!P8IWE#B`DX.P-@.`,("+@;,&@
MX0(@E>`#4);@!%"5X'ABG>4,0"[@X"V"X`!`).!@`:#A!$"5X`-@EN`.X);@
M`%`LX(!BG>4"4"7@XDV$X`50GN!B(:#A`V"6X(CBG>4,P);@`F`@X.1=A>`$
M8";@9$&@X0;`G.`#,)[@"C"3X.7-C.``,)/@!``BX`4`(.!E@8C@`#"3X`!@
MH./L/8/@`#"!Y2`PD>4)D)S@$("!Y0L`E.`(D('E`R"2X!@`@>4D,)_E(""!
MY21@@>4`()/EE#*=Y0(@,^``,*#C`0``&J??C>+PC[WH?O3_Z_">`0`00"WI
M@`"@XZ'T_^L/>Y_M`""@XW@@@.4`>X#M#7N?[0)[@.T->Y_M!'N`[0U[G^T&
M>X#M#7N?[0A[@.T->Y_M"GN`[0Q[@.T0@+WH`/`@XP$C16<`````B:O-[P``
M``#^W+J8`````'94,A``````\.'2PP```````````````/!'+>D"8*#A`#"@
MXRAPD.4`4*#A+."0Y0%`H.$P()#EAL&'X#00D.4'`%SAQ@^@X0[@T^`!```J
M`2"2X@`0H>(L,(7EICZ@X8`Q@^$X@(7B`C"3X"C`A>6@'J'@>`"5Y3`PA>4`
M`%#C-!"%Y2```!H_`%;C+P``VD"01N(I8Z#A`7"&X@=SA.`$$*#A"#"@X4!`
MA.(`X)'E$!"!X@S`$>40,(/B"``1Y00@$>4$`%'A$.`#Y0S``^4(``/E!"`#
MY?/__QH!0*#A!0"@X7/\_^L'`%3AZ___&@9C2>`&(*#A!Q"@X0@`H.$*]/_K
M>&"%Y?"'O>A`<&#B!!"@X08`5^$``(C@!G"@H0<@H.$!]/_K>#"5Y0,PA^!X
M,(7E0`!3X_"'O1@%`*#A!V!&X`=`A.!:_/_KS?__Z@1PH.'F___J\$$MZ3AP
M@>(!0*#A*#"1Y0!0H.$P8)'E?Q#@XS./O^;3,>7G-F^_Y@$@@^(X`%+C`@"'
MX`,0Q^<\``#:0"!BX@`0H.-/]/_K!`"@X4/\_^L'`*#A.""@XP`0H.-)]/_K
M!`"@X7!@A.5T@(3E._S_ZP,PU.4`,,7E!`"@X;(PU.$!,,7E`#"4Y2,TH.$"
M,,7E`#"4Y0,PQ>4+,-3E!##%Y;HPU.$%,,7E"#"4Y2,TH.$&,,7E"#"4Y0<P
MQ>43,-3E"##%Y;(QU.$),,7E$#"4Y2,TH.$*,,7E$#"4Y0LPQ>4;,-3E###%
MY;HQU.$-,,7E&#"4Y2,TH.$.,,7E&#"4Y0\PQ>4C,-3E$##%Y;(RU.$1,,7E
M(#"4Y2,TH.$2,,7E(#"4Y1,PQ>7P0;WHIO/_ZC@@8N(`$*#C$O3_Z\?__^H(
M,)_E`S"/X``PD^6\\__J=%\```A`+>D(@+WH`0`"`#T```!`````"P```$``
M```0````0````"8```!`````-0```$`````#````0`````8```!`````%```
M`$`````.````0`````T```!`````)0```$`````2````0````"@```!`````
M`@```$`````8````0`````D```!`````"@```$```````````````"5S+R5S
M````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`+@``
M`%!!4E]414U0`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O````
M4$523#5,24(`````4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])
M3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<`
M``!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?
M5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"
M04Q?0TQ%04X`````,0```&QS965K(&9A:6QE9`````!R96%D(&9A:6QE9`!,
M1%],24)205)97U!!5$@`4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A
M<BT`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@``4$%42`````!P87)L`````"YP87(`````<VAO<G0@
M<F5A9```)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M
M<"TE=2TE=25S`````!@```!P97)L`````#````!005(Z.E!A8VME<CHZ5D52
M4TE/3@`````Q+C`V,P```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T
M;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````+64``"TM``!54T52````
M`%5315).04U%`````%1%35!$25(`5$U0`"]T;7``````979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U
M;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H
M)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I
M>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%
M7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S
M:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@
M9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ
M92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY
M("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@
M("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ
M90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D
M("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD[
M"FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I
M('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]
M"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F
M:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F
M:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H
M<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*
M<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G
M35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%4
M12`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI
M.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\
M/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@
M)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R
M96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL
M96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64[
M"FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES
M=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.
M('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA
M;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<
M)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO
M=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*
M;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)
M0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO
M<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@
M<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A
M(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G
M:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG
M("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'
M24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I
M8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?
M<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D
M8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U
M;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U
M9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S
M971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE
M.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E
M="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`[
M"B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I
M<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@
M97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U
M=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R
M8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@
M.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_
M.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT
M*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE
M.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E
M<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0[
M"GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN
M9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN
M9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#
M3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]
M($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T
M96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN
M9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L
M<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M
M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*
M;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U
M;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q
M=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II
M<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A21553
M12!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L
M;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I
M9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A
M9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@
M>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2![
M"F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T
M($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@
M)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]
M"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF
M("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG
M*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E
M;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D
M<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ
M1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE
M=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q
M6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E
M860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F
M:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A
M;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*
M<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968[
M"B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@
M*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE
M<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U
M;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY
M("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA
M<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF
M:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S
M(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H
M;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M
M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD
M?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF
M("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D
M<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L
M("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT
M('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE
M?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L
M:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S
M(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM
M>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL
M92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@
M)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I
M;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^
M+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M
M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*
M<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E
M9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N
M86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A
M<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII
M9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ
M4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@
M)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C
M:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H
M+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@
M,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN
M9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ
M6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL
M96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*
M;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M
M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O
M9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T
M('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E
M<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB
M97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M
M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[
M87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6
M>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U
M=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D
M>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=
M*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R
M86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@
M0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E
M($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E
M<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D
M97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@
M=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!
M4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*
M;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@
M/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(
M12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I
M8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I
M"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H
M95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C
M86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I
M('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@
M,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER
M.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*
M;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA
M;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I
M('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P
M96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O
M;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF
M(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@
M;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS
M=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.
M04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O
M9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?
M5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X]
M(#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?
M4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB
M*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E
M86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6
M>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI
M;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P
M(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN
M960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC
M:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D
M96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.
M5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@
M>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.
M140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE
M=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%
M04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF
M("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]
M"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2![
M"G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*
M?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L
M(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA
M<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV
M96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*
M<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI0
M05(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O
M<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@
M9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`[
M"GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ
M.PI?7T5.1%]?"@!P97)L>'-I+F,```"(10$`G$(!``````!<0P$`8$,!`'Q%
M`0"D0@$`A$4!``````!H10$`<$4!````````0T%#2$4``#T```!`````"P``
M`$`````0````0````"8```!`````-0```$`````#````0`````8```!`````
M%````$`````.````0`````T```!`````)0```$`````2````0````"@```!`
M`````@```$`````8````0`````D```!`````"@```$````````````````B1
M_W\!````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#0
M%0$`J!4!``````````````````````````````````$````$`P```0```!0#
M```!````'@,```P```"T#P$`#0```*1!`0`9````Z)X!`!L````$````&@``
M`.R>`0`<````!````/7^_V^T`0$`!0```%0)`0`&````Y`0!``H```!2`P``
M"P```!`````5``````````,`````H`$``@```.@!```4````$0```!<```#,
M#0$`$0```)0-`0`2````.````!,````(````_O__;S0-`0#___]O`@```/#_
M_V^F#`$`````````````````````````````````````````````````````
M````````````")\!````````````P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`
MP`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`
M#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/
M`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!
M`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`
MP`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!`,`/`0#`#P$`P`\!````````
M````L!(!````````````"E!!4BYP;0H`````D$4!`$=#0SH@*$UA9V5I82`Q
M,BXS+C`M,RYM9V$Y*2`Q,BXS+C``03(```!A96%B:0`!*`````4W+4$`!@H'
M00@!"0(*!!($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T<G1A8@`N:6YT97)P
M`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%2
M32YE>&ED>``N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1A
M=&$N<F5L+G)O`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N
M05)-+F%T=')I8G5T97,`````````````````````````````````````````
M``````````````L````!`````@```%0!`0!4`0``&0```````````````0``
M```````3````!P````(```!P`0$`<`$``"0```````````````0`````````
M)@````<````"````E`$!`)0!```@```````````````$`````````#0```#V
M__]O`@```+0!`0"T`0``,`,```4`````````!`````0````^````"P````(`
M``#D!`$`Y`0``'`$```&`````0````0````0````1@````,````"````5`D!
M`%0)``!2`P`````````````!`````````$X```#___]O`@```*8,`0"F#```
MC@````4``````````@````(```!;````_O__;P(````T#0$`-`T``&`````&
M`````@````0`````````:@````D````"````E`T!`)0-```X````!0``````
M```$````"````',````)````0@```,P-`0#,#0``Z`$```4````6````!```
M``@```!\`````0````8```"T#P$`M`\```P```````````````0`````````
M=P````$````&````P`\!`,`/``#P`@`````````````$````!````((````!
M````!@```+`2`0"P$@``]"X`````````````"`````````"(`````0````8`
M``"D00$`I$$```@```````````````0`````````C@````$````"````K$$!
M`*Q!```H0@`````````````$`````````)8````!``!P@@```-2#`0#4@P``
M"`````T`````````!`````````"A`````0````(```#<@P$`W(,```0`````
M``````````0`````````JP````X````#````Z)X!`.B.```$````````````
M```$````!````+<````/`````P```.R>`0#LC@``!```````````````!```
M``0```##`````0````,```#PG@$`\(X``!<```````````````0`````````
MT`````8````#````")\!``B/``#X````!@`````````$````"````-D````!
M`````P````"@`0``D```#`$`````````````!`````0```#>`````0````,`
M```,H0$`#)$``!@```````````````0`````````Y`````@````#````**$!
M`"21```H```````````````(`````````.D````!````,``````````DD0``
M(P```````````````0````$```#R`````P``<```````````1Y$``#,`````
M``````````$``````````0````,``````````````'J1```"`0``````````
*```!````````````
